| Safe Haskell | Safe |
|---|---|
| Language | Haskell2010 |
Vgrep.Ansi.Vty.Attributes
Documentation
A display attribute defines the Color and Style of all the characters rendered after the attribute is applied.
At most 256 colors, picked from a 240 and 16 color palette, are possible for the background and foreground. The 240 colors and 16 colors are points in different palettes. See Color for more information.